use serde::{Deserialize, Serialize};

#[derive(Debug, Clone, Copy, Deserialize, Serialize, PartialEq, Eq)]
pub enum KarlenderColor {
    Red,
    Green,
    Blue,
    Orange,
    Black,

    RedTP,
    GreenTP,
    BlueTP,
    OrangeTP,
    BlackTP,
}

impl KarlenderColor {
    pub fn style_class(&self) -> &'static str {
        match self {
            KarlenderColor::Red => "calendar-color-red",
            KarlenderColor::Green => "calendar-color-green",
            KarlenderColor::Blue => "calendar-color-blue",
            KarlenderColor::Orange => "calendar-color-orange",
            KarlenderColor::Black => "calendar-color-black",

            KarlenderColor::RedTP => "calendar-color-red-tp",
            KarlenderColor::GreenTP => "calendar-color-green-tp",
            KarlenderColor::BlueTP => "calendar-color-blue-tp",
            KarlenderColor::OrangeTP => "calendar-color-orange-tp",
            KarlenderColor::BlackTP => "calendar-color-black-tp",
        }
    }

    pub fn transparent(&self) -> Self {
        match self {
            KarlenderColor::Red => KarlenderColor::RedTP,
            KarlenderColor::Green => KarlenderColor::GreenTP,
            KarlenderColor::Blue => KarlenderColor::BlueTP,
            KarlenderColor::Orange => KarlenderColor::OrangeTP,
            KarlenderColor::Black => KarlenderColor::BlackTP,

            KarlenderColor::RedTP => KarlenderColor::RedTP,
            KarlenderColor::GreenTP => KarlenderColor::GreenTP,
            KarlenderColor::BlueTP => KarlenderColor::BlueTP,
            KarlenderColor::OrangeTP => KarlenderColor::OrangeTP,
            KarlenderColor::BlackTP => KarlenderColor::BlackTP,
        }
    }
}

impl From<String> for KarlenderColor {
    fn from(s: String) -> Self {
        match s.as_str() {
            "Red" => KarlenderColor::Red,
            "Green" => KarlenderColor::Green,
            "Blue" => KarlenderColor::Blue,
            "Orange" => KarlenderColor::Orange,
            "Black" => KarlenderColor::Black,
            _ => KarlenderColor::Black,
        }
    }
}

impl ToString for KarlenderColor {
    fn to_string(&self) -> String {
        match self {
            KarlenderColor::Red => "Red".into(),
            KarlenderColor::Green => "Green".into(),
            KarlenderColor::Blue => "Blue".into(),
            KarlenderColor::Orange => "Orange".into(),
            KarlenderColor::Black => "Black".into(),

            KarlenderColor::RedTP => "Red".into(),
            KarlenderColor::GreenTP => "Green".into(),
            KarlenderColor::BlueTP => "Blue".into(),
            KarlenderColor::OrangeTP => "Orange".into(),
            KarlenderColor::BlackTP => "Black".into(),
        }
    }
}
